//
// This file is part of Nolimips, a MIPS simulator with unlimited registers
// Copyright (C) 2003, 2004, 2006 Benoit Perrot <benoit@lrde.epita.fr>
//
// Nolimips is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// Nolimips is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Nolimips.  If not, see <http://www.gnu.org/licenses/>.
//
#ifndef INST_REGISTER_HH
# define INST_REGISTER_HH

# include <ostream>

namespace inst
{

  class Register
  {
  public:
    enum kind_type
      {
        /// Generic (processor, coprocessor) kind ($0, $1, etc.)
        generic,
        /// General purpose (processor) register ($zero, $a0, etc.)
        general,
        /// Unlimited (processor) register ($x2097, etc.)
        unlimited
      };

  public:
    Register(kind_type kind, int index);
    Register(const Register &reg);

    Register &operator=(const Register &reg);

  public:
    void set_kind(kind_type kind);
    kind_type get_kind() const;

    int get_index() const;

  public:
    void write(std::ostream &ostr) const;

  protected:
    kind_type kind_;
    int index_;
  };

  std::ostream &
  operator<<(std::ostream &ostr, const Register &reg);

} // namespace inst

# include "inst/register.hxx"

#endif // !INST_REGISTER_HH
