//
// This file is part of Nolimips, a MIPS simulator with unlimited registers
// Copyright (C) 2006 Benoit Perrot <benoit@lrde.epita.fr>
//
// Nolimips is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// Nolimips is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Nolimips.  If not, see <http://www.gnu.org/licenses/>.
//
#ifndef INST_REGISTER_HXX
# define INST_REGISTER_HXX

# include "inst/register.hh"

namespace inst
{

  //
  inline
  Register::Register(Register::kind_type kind, int index):
    kind_(kind), index_(index)
  {
  }
  inline
  Register::Register(const Register &reg):
    kind_(reg.kind_), index_(reg.index_)
  {
  }

  inline Register &
  Register::operator=(const Register &reg)
  {
    kind_ = reg.kind_;
    index_ = reg.index_;
    return (*this);
  }

  //
  inline void
  Register::set_kind(Register::kind_type kind)
  {
    kind_ = kind;
  }
  inline Register::kind_type
  Register::get_kind() const
  {
    return kind_;
  }

  inline int
  Register::get_index() const
  {
    return index_;
  }

  //
  inline void
  Register::write(std::ostream &ostr) const
  {
    if (kind_ != unlimited)
      ostr << "$" << index_;
    else
      ostr << "$x" << index_;
  }

  //
  inline std::ostream &
  operator<<(std::ostream &ostr, const Register &reg)
  {
    reg.write(ostr);
    return ostr;
  }

} // namespace inst

#endif // !INST_REGISTER_HXX
